@@ -6,14 +6,17 @@ package Alien::scriptaculous;
 use strict;
 use warnings;
 use Carp;
+use File::Spec;
 use File::Copy qw(copy);
 use File::Path qw(mkpath);
+use File::Basename qw(dirname);
+use Alien::Prototype;
 
 ###############################################################################
 # Version number
 ###############################################################################
 our $SCRIPTACULOUS_VERSION = '1.7.1_beta3';
-our $VERSION = '1.7.1.1_03';
+our $VERSION = '1.7.1.2_03';
 
 ###############################################################################
 # Subroutine:   version()
@@ -38,6 +41,34 @@ sub path {
     return $base;
 }
 
+###############################################################################
+# Subroutine:   to_blib()
+###############################################################################
+# Returns a hash containing paths to the source files to be copied, and their
+# relative destinations.
+###############################################################################
+sub to_blib {
+    my $class = shift;
+    my $path  = $class->path();
+    my @files = map { "$_.js" }
+                qw( builder controls dragdrop effects scriptaculous slider
+                    sound
+                );
+    my %blib  = map { (File::Spec->catfile($path,'src',$_) => $_) } @files;
+    return %blib;
+}
+
+###############################################################################
+# Subroutine:   files()
+###############################################################################
+# Returns the list of files that are installed by Alien::scriptaculous.
+###############################################################################
+sub files {
+    my $class = shift;
+    my %blib  = $class->to_blib();
+    return sort values %blib;
+}
+
 ###############################################################################
 # Subroutine:   install($destdir)
 # Parameters:   $destdir    - Destination directory
@@ -47,14 +78,22 @@ sub path {
 ###############################################################################
 sub install {
     my ($class, $destdir) = @_;
-    if (!-d $destdir) {
-        mkpath( $destdir ) || croak "can't create '$destdir'; $!";
-    }
 
-    my $path = $class->path();
-    my @jsfiles = grep { -f $_ } glob "$path/*/*.js";
-    foreach my $file (@jsfiles) {
-        copy( $file, $destdir ) || croak "can't copy '$file' to '$destdir'; $!";
+    # install Prototype
+    Alien::Prototype->install( $destdir );
+
+    # install our files
+    my %blib = $class->to_blib();
+    while (my ($srcfile, $dest) = each %blib) {
+        # get full path to destination file
+        my $destfile = File::Spec->catfile( $destdir, $dest );
+        # create any required install directories
+        my $instdir = dirname( $destfile );
+        if (!-d $instdir) {
+            mkpath( $instdir ) || croak "can't create '$instdir'; $!";
+        }
+        # install the file
+        copy( $srcfile, $destfile ) || croak "can't copy '$srcfile' to '$instdir'; $!";
     }
 }
 
@@ -92,6 +131,15 @@ is the version number of the Perl wrapper).
 
 Returns the path to the available copy of script.aculo.us. 
 
+=item to_blib()
+
+Returns a hash containing paths to the source files to be copied, and their
+relative destinations. 
+
+=item files()
+
+Returns the list of files that are installed by Alien::scriptaculous. 
+
 =item install($destdir)
 
 Installs the script.aculo.us Javascript libraries into the given
@@ -112,6 +160,7 @@ This is free software; you can redistribute it and/or modify it under the same t
 =head1 SEE ALSO
 
 http://script.aculo.us/,
+L<Alien::Prototype>,
 L<Alien>.
 
 =cut
